summaryrefslogtreecommitdiff
path: root/src/node_binding.h
diff options
context:
space:
mode:
authorlegendecas <legendecas@gmail.com>2022-11-21 01:37:56 +0800
committerlegendecas <legendecas@gmail.com>2022-11-29 00:23:08 +0800
commit71ff89f9299d1d10a4c424da23d827e5458dadff (patch)
tree8c559cc2359736a16c3726db0c180f9704465669 /src/node_binding.h
parentd09f0c4dbc28acd89519064cec0b02d51842d985 (diff)
downloadnode-new-71ff89f9299d1d10a4c424da23d827e5458dadff.tar.gz
src: rename internal module declaration as internal bindings
This is a continuation of the name reification on the internal bindings. Renames NODE_MODULE_CONTEXT_AWARE_INTERNAL and NODE_MODULE_EXTERNAL_REFERENCE to NODE_BINDING_CONTEXT_AWARE_INTERNAL and NODE_BINDING_EXTERNAL_REFERENCE respectively. PR-URL: https://github.com/nodejs/node/pull/45551 Refs: https://github.com/nodejs/node/issues/44036 Reviewed-By: Joyee Cheung <joyeec9h3@gmail.com> Reviewed-By: Rafael Gonzaga <rafael.nunu@hotmail.com> Reviewed-By: Daeyeon Jeong <daeyeon.dev@gmail.com> Reviewed-By: Jacob Smith <jacob@frende.me> Reviewed-By: Yagiz Nizipli <yagiz@nizipli.com>
Diffstat (limited to 'src/node_binding.h')
-rw-r--r--src/node_binding.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/node_binding.h b/src/node_binding.h
index 5bced5b414..13681bac67 100644
--- a/src/node_binding.h
+++ b/src/node_binding.h
@@ -24,7 +24,7 @@ static_assert(static_cast<int>(NM_F_LINKED) ==
static_cast<int>(node::ModuleFlags::kLinked),
"NM_F_LINKED != node::ModuleFlags::kLinked");
-#define NODE_MODULE_CONTEXT_AWARE_CPP(modname, regfunc, priv, flags) \
+#define NODE_BINDING_CONTEXT_AWARE_CPP(modname, regfunc, priv, flags) \
static node::node_module _module = { \
NODE_MODULE_VERSION, \
flags, \
@@ -44,8 +44,8 @@ void napi_module_register_by_symbol(v8::Local<v8::Object> exports,
namespace node {
-#define NODE_MODULE_CONTEXT_AWARE_INTERNAL(modname, regfunc) \
- NODE_MODULE_CONTEXT_AWARE_CPP(modname, regfunc, nullptr, NM_F_INTERNAL)
+#define NODE_BINDING_CONTEXT_AWARE_INTERNAL(modname, regfunc) \
+ NODE_BINDING_CONTEXT_AWARE_CPP(modname, regfunc, nullptr, NM_F_INTERNAL)
// Globals per process
// This is set by node::Init() which is used by embedders
@@ -83,10 +83,10 @@ class DLib {
};
// Call _register<module_name> functions for all of
// the built-in modules. Because built-in modules don't
// use the __attribute__((constructor)). Need to
// explicitly call the _register* functions.
-void RegisterBuiltinModules();
+void RegisterBuiltinBindings();
void GetInternalBinding(const v8::FunctionCallbackInfo<v8::Value>& args);
void GetLinkedBinding(const v8::FunctionCallbackInfo<v8::Value>& args);
void DLOpen(const v8::FunctionCallbackInfo<v8::Value>& args);
@@ -83,10 +83,10 @@ class DLib {
};
// Call _register<module_name> functions for all of
-// the built-in modules. Because built-in modules don't
+// the built-in bindings. Because built-in bindings don't
// use the __attribute__((constructor)). Need to
// explicitly call the _register* functions.